@@ -48,10 +48,13 @@ class Application(Gtk.Application):
 
     @log
     def __init__(self):
-        Gtk.Application.__init__(self, application_id='org.gnome.Music',
-                                 flags=Gio.ApplicationFlags.FLAGS_NONE)
+        super().__init__(
+            application_id='org.gnome.Music',
+            flags=Gio.ApplicationFlags.FLAGS_NONE)
+
         GLib.set_application_name(_("Music"))
         GLib.set_prgname('gnome-music')
+        GLib.setenv("PULSE_PROP_media.role", "music", True)
         self._settings = Gio.Settings.new('org.gnome.Music')
         self._init_style()
         self._window = None
@@ -63,8 +66,8 @@ class Application(Gtk.Application):
         css_provider.load_from_file(css_provider_file)
         screen = Gdk.Screen.get_default()
         style_context = Gtk.StyleContext()
-        style_context.add_provider_for_screen(screen, css_provider,
-                                              Gtk.STYLE_PROVIDER_PRIORITY_USER)
+        style_context.add_provider_for_screen(
+            screen, css_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
 
     @log
     def _build_app_menu(self):
