@@ -151,8 +151,8 @@ class Grilo(GObject.GObject):
                         # todo: remove one single url
                         try:
                             self.changed_media_ids.append(media.get_id())
-                        except Exception as e:
-                            logger.warn("Skipping %s", media)
+                        except Exception:
+                            logger.warning("Skipping {}".format(media))
 
                 if self.changed_media_ids == []:
                     self.pending_changed_medias = []
@@ -171,8 +171,9 @@ class Grilo(GObject.GObject):
                         GLib.Source.remove(self.pending_event_id)
                         self.pending_event_id = 0
                     self.pending_event_id = GLib.timeout_add(self.CHANGED_MEDIA_SIGNAL_TIMEOUT, self.emit_change_signal)
-        except Exception as e:
-            logger.warn("Exception in _on_content_changed: %s", e)
+        except Exception as error:
+            logger.warning(
+                "Exception in _on_content_changed: {}".format(error))
         finally:
             self.pending_changed_medias = []
             if self.content_changed_timeout is not None:
@@ -197,8 +198,8 @@ class Grilo(GObject.GObject):
             try:
                 pluginRegistry.unregister_source(mediaSource)
             except GLib.GError:
-                logger.error("Failed to unregister %s.",
-                             mediaSource.get_id())
+                logger.error(
+                    "Failed to unregister {}".format(mediaSource.get_id()))
             return
 
         id = mediaSource.get_id()
@@ -232,7 +233,7 @@ class Grilo(GObject.GObject):
                 self.emit('new-source-added', mediaSource)
 
         except Exception as e:
-            logger.debug("Source %s: exception %s", id, e)
+            logger.debug("Source {}: exception {}".format(id, e))
 
     @log
     def _on_source_removed(self, pluginRegistry, mediaSource):
@@ -293,6 +294,9 @@ class Grilo(GObject.GObject):
             options.set_count(count)
 
         def _callback(source, param, item, remaining, data, error):
+            if error:
+                logger.warning(
+                    "Error {}: {}".format(error.domain, error.message))
             callback(source, param, item, remaining, data)
         self.tracker.query(query, self.METADATA_KEYS, options, _callback, data)
 
@@ -313,9 +317,11 @@ class Grilo(GObject.GObject):
 
         # FIXME: We assume this is the tracker plugin.
         # FIXME: Doing this async crashes
-        self.tracker.store_metadata_sync(song_item,
-                                         [Grl.METADATA_KEY_FAVOURITE],
-                                         Grl.WriteFlags.NORMAL)
+        try:
+            self.tracker.store_metadata_sync(
+                song_item, [Grl.METADATA_KEY_FAVOURITE], Grl.WriteFlags.NORMAL)
+        except GLib.Error as error:
+            logger.warning("Error {}: {}".format(error.domain, error.message))
 
     @log
     def set_favorite(self, song_item, favorite):
@@ -334,11 +340,17 @@ class Grilo(GObject.GObject):
 
         @log
         def _search_callback(source, param, item, remaining, data, error):
+            if error:
+                logger.warning(
+                    "Error {}: {}".format(error.domain, error.message))
             callback(source, param, item, remaining, data)
             self._search_callback_counter += 1
 
         @log
         def _multiple_search_callback(source, param, item, remaining, data, error):
+            if error:
+                logger.warning(
+                    "Error {}: {}".format(error.domain, error.message))
             callback(source, param, item, remaining, data)
 
         if self.search_source:
@@ -393,8 +405,11 @@ class Grilo(GObject.GObject):
 
         # FIXME: We assume this is the tracker plugin.
         # FIXME: Doing this async crashes
-        self.tracker.store_metadata_sync(media, [Grl.METADATA_KEY_PLAY_COUNT],
-                                         Grl.WriteFlags.NORMAL)
+        try:
+            self.tracker.store_metadata_sync(
+                media, [Grl.METADATA_KEY_PLAY_COUNT], Grl.WriteFlags.NORMAL)
+        except GLib.Error as error:
+            logger.warning("Error {}: {}".format(error.domain, error.message))
 
     @log
     def set_last_played(self, media):
@@ -406,8 +421,11 @@ class Grilo(GObject.GObject):
         media.set_last_played(GLib.DateTime.new_now_utc())
         # FIXME: We assume this is the tracker plugin.
         # FIXME: Doing this async crashes
-        self.tracker.store_metadata_sync(media, [Grl.METADATA_KEY_LAST_PLAYED],
-                                         Grl.WriteFlags.NORMAL)
+        try:
+            self.tracker.store_metadata_sync(
+                media, [Grl.METADATA_KEY_LAST_PLAYED], Grl.WriteFlags.NORMAL)
+        except GLib.Error as error:
+            logger.warning("Error {}: {}".format(error.domain, error.message))
 
     @log
     def songs_available(self, callback):
@@ -421,7 +439,7 @@ class Grilo(GObject.GObject):
             try:
                 has_next = conn.next_finish(res)
             except GLib.Error as err:
-                logger.warn("Error: %s, %s", err.__class__, err)
+                logger.warning("Error: {}, {}".format(err.__class__, err))
                 callback(False)
                 return
 
@@ -438,7 +456,7 @@ class Grilo(GObject.GObject):
             try:
                 cursor = conn.query_finish(res)
             except GLib.Error as err:
-                logger.warn("Error: %s, %s", err.__class__, err)
+                logger.warning("Error: {}, {}".format(err.__class__, err))
                 callback(False)
                 return
 
@@ -461,7 +479,7 @@ class Grilo(GObject.GObject):
             try:
                 has_next = conn.next_finish(res)
             except GLib.Error as err:
-                logger.warn("Error: %s, %s", err.__class__, err)
+                logger.warning("Error: {},{}".format(err.__class__, err))
                 callback(False)
                 return
 
@@ -478,7 +496,7 @@ class Grilo(GObject.GObject):
             try:
                 cursor = conn.query_finish(res)
             except GLib.Error as err:
-                logger.warn("Error: %s, %s", err.__class__, err)
+                logger.warning("Error: {}, {}".format(err.__class__, err))
                 callback(False)
                 return
 
