@@ -31,6 +31,7 @@
 # delete this exception statement from your version.
 
 from collections import deque
+from enum import IntEnum
 import logging
 from random import randint
 import time
@@ -96,6 +97,11 @@ class Player(GObject.GObject):
         'thumbnail-updated': (GObject.SignalFlags.RUN_FIRST, None, ()),
     }
 
+    class Field(IntEnum):
+        """Enum for player model fields"""
+        SONG = 0
+        DISCOVERY_STATUS = 1
+
     def __repr__(self):
         return '<Player>'
 
@@ -107,9 +113,8 @@ class Player(GObject.GObject):
         self.playlist = None
         self.playlistType = None
         self.playlistId = None
-        self.playlistField = None
         self.currentTrack = None
-        self.currentTrackUri = None
+        self._current_track_uri = None
         self._missingPluginMessages = []
 
         Gst.init(None)
@@ -138,11 +143,13 @@ class Player(GObject.GObject):
         self.bus.connect('message::eos', self._on_bus_eos)
         self._setup_view()
 
-        self.playlist_insert_handler = 0
-        self.playlist_delete_handler = 0
-
         self._lastfm = LastFmScrobbler()
 
+    @GObject.Property
+    @log
+    def current_track_uri(self):
+        return self._current_track_uri
+
     @log
     def _on_replaygain_setting_changed(self, settings, value):
         self.replaygain = settings.get_value('replaygain') is not None
@@ -186,7 +193,7 @@ class Player(GObject.GObject):
     def discover_item(self, item, callback, data=None):
         url = item.get_url()
         if not url:
-            logger.warn("The item %s doesn't have a URL set", item)
+            logger.warning("The item {} doesn't have a URL set".format(item))
             return
 
         if not url.startswith("file://"):
@@ -329,18 +336,20 @@ class Player(GObject.GObject):
         media = self.get_current_media()
         if media is not None:
             if self.currentTrack and self.currentTrack.valid():
-                currentTrack = self.playlist.get_iter(self.currentTrack.get_path())
-                self.playlist.set_value(currentTrack, self.discovery_status_field, DiscoveryStatus.FAILED)
+                currentTrack = self.playlist.get_iter(
+                    self.currentTrack.get_path())
+                cols = self.playlist[currentTrack]
+                cols[self.Field.DISCOVERY_STATUS] = DiscoveryStatus.FAILED
             uri = media.get_url()
         else:
             uri = 'none'
-        logger.warn('URI: %s', uri)
+        logger.warning('URI: {}'.format(uri))
         error, debug = message.parse_error()
         debug = debug.split('\n')
         debug = [('     ') + line.lstrip() for line in debug]
         debug = '\n'.join(debug)
-        logger.warn('Error from element %s: %s', message.src.get_name(), error.message)
-        logger.warn('Debugging info:\n%s', debug)
+        logger.warning('Error from element {}: {}'.format(message.src.get_name(), error.message))
+        logger.warning('Debugging info:\n{}'.format(debug))
         self.play_next()
         return True
 
@@ -357,8 +366,6 @@ class Player(GObject.GObject):
                 currentTrack = self.playlist.get_path(self.playlist.get_iter_first())
                 if currentTrack:
                     self.currentTrack = Gtk.TreeRowReference.new(self.playlist, currentTrack)
-                    self.currentTrackUri = self.playlist.get_value(
-                        self.playlist.get_iter(self.currentTrack.get_path()), 5).get_url()
                 else:
                     self.currentTrack = None
                 self.load(self.get_current_media())
@@ -374,13 +381,31 @@ class Player(GObject.GObject):
     @log
     def _on_glib_idle(self):
         self.currentTrack = self.nextTrack
-        if self.currentTrack and self.currentTrack.valid():
-            self.currentTrackUri = self.playlist.get_value(
-                self.playlist.get_iter(self.currentTrack.get_path()), 5).get_url()
         self.play()
 
     @log
-    def _on_playlist_size_changed(self, path, _iter=None, data=None):
+    def add_song(self, model, path, _iter):
+        new_row = model[_iter]
+        self.playlist.insert_with_valuesv(
+            int(path.to_string()),
+            [self.Field.SONG, self.Field.DISCOVERY_STATUS],
+            [new_row[5], new_row[self._discovery_status_field]])
+        self._validate_next_track()
+        self._sync_prev_next()
+
+    @log
+    def remove_song(self, model, path):
+        iter_remove = self.playlist.get_iter_from_string(path.to_string())
+        if (self.currentTrack.get_path().to_string() == path.to_string()):
+            if self.has_next():
+                self.play_next()
+            elif self.has_previous():
+                self.play_previous()
+            else:
+                self.Stop()
+
+        self.playlist.remove(iter_remove)
+        self._validate_next_track()
         self._sync_prev_next()
 
     @log
@@ -593,15 +618,20 @@ class Player(GObject.GObject):
 
         if self.currentTrack and self.currentTrack.valid():
             currentTrack = self.playlist.get_iter(self.currentTrack.get_path())
+            uri = self.playlist[currentTrack][self.Field.SONG].get_url()
+            self._current_track_uri = uri
             self.emit('playlist-item-changed', self.playlist, currentTrack)
             self.emit('current-changed')
+        else:
+            self._current_track_uri = None
 
         self._validate_next_track()
 
     def _on_next_item_validated(self, info, error, _iter):
         if error:
             print("Info %s: error: %s" % (info, error))
-            self.playlist.set_value(_iter, self.discovery_status_field, DiscoveryStatus.FAILED)
+            failed = DiscoveryStatus.FAILED
+            self.playlist[_iter][self.Field.DISCOVERY_STATUS] = failed
             nextTrack = self.playlist.iter_next(_iter)
 
             if nextTrack:
@@ -618,15 +648,15 @@ class Player(GObject.GObject):
             return
 
         _iter = self.playlist.get_iter(self.nextTrack.get_path())
-        status = self.playlist.get_value(_iter, self.discovery_status_field)
-        nextSong = self.playlist.get_value(_iter, self.playlistField)
-        url = self.playlist.get_value(_iter, 5).get_url()
+        status = self.playlist[_iter][self.Field.DISCOVERY_STATUS]
+        next_song = self.playlist[_iter][self.Field.SONG]
+        url = next_song.get_url()
 
         # Skip remote songs discovery
         if url.startswith('http://') or url.startswith('https://'):
             return False
         elif status == DiscoveryStatus.PENDING:
-            self.discover_item(nextSong, self._on_next_item_validated, _iter)
+            self.discover_item(next_song, self._on_next_item_validated, _iter)
         elif status == DiscoveryStatus.FAILED:
             GLib.idle_add(self._validate_next_track)
 
@@ -687,11 +717,7 @@ class Player(GObject.GObject):
 
         self.stop()
         self.currentTrack = self.nextTrack
-
-        if self.currentTrack and self.currentTrack.valid():
-            self.currentTrackUri = self.playlist.get_value(
-                self.playlist.get_iter(self.currentTrack.get_path()), 5).get_url()
-            self.play()
+        self.play()
 
     @log
     def play_previous(self):
@@ -710,10 +736,7 @@ class Player(GObject.GObject):
         self.stop()
 
         self.currentTrack = self._get_previous_track()
-        if self.currentTrack and self.currentTrack.valid():
-            self.currentTrackUri = self.playlist.get_value(
-                self.playlist.get_iter(self.currentTrack.get_path()), 5).get_url()
-            self.play()
+        self.play()
 
     @log
     def play_pause(self):
@@ -722,34 +745,40 @@ class Player(GObject.GObject):
         else:
             self.set_playing(True)
 
+    @log
+    def _create_model(self, model, model_iter):
+        new_model = Gtk.ListStore(GObject.TYPE_OBJECT, GObject.TYPE_INT)
+        song_id = model[model_iter][5].get_id()
+        new_path = None
+        for row in model:
+            current_iter = new_model.insert_with_valuesv(
+                -1, [self.Field.SONG, self.Field.DISCOVERY_STATUS],
+                [row[5], row[self._discovery_status_field]])
+            if row[5].get_id() == song_id:
+                new_path = new_model.get_path(current_iter)
+
+        return new_model, new_path
+
     # FIXME: set the discovery field to 11 to be safe, but for some
     # models it is 12.
     @log
-    def set_playlist(self, type, id, model, iter, field,
-                     discovery_status_field=11):
-        old_playlist = self.playlist
-        if old_playlist != model:
-            self.playlist = model
-            if self.playlist_insert_handler:
-                old_playlist.disconnect(self.playlist_insert_handler)
-            if self.playlist_delete_handler:
-                old_playlist.disconnect(self.playlist_delete_handler)
+    def set_playlist(
+            self, type_, id_, model, iter_, discovery_status_field=11):
+        self._discovery_status_field = discovery_status_field
+        self.playlist, playlist_path = self._create_model(model, iter_)
+        self.currentTrack = Gtk.TreeRowReference.new(
+            self.playlist, playlist_path)
 
-        self.playlistType = type
-        self.playlistId = id
-        self.currentTrack = Gtk.TreeRowReference.new(model, model.get_path(iter))
-        if self.currentTrack and self.currentTrack.valid():
-            self.currentTrackUri = self.playlist.get_value(
-                self.playlist.get_iter(self.currentTrack.get_path()), 5).get_url()
-        self.playlistField = field
-        self.discovery_status_field = discovery_status_field
-
-        if old_playlist != model:
-            self.playlist_insert_handler = model.connect('row-inserted', self._on_playlist_size_changed)
-            self.playlist_delete_handler = model.connect('row-deleted', self._on_playlist_size_changed)
+        if type_ != self.playlistType or id_ != self.playlistId:
             self.emit('playlist-changed')
-        self.emit('current-changed')
 
+        self.playlistType = type_
+        self.playlistId = id_
+
+        if self._get_playing():
+            self._sync_prev_next()
+
+        self.emit('current-changed')
         GLib.idle_add(self._validate_next_track)
 
     @log
@@ -946,9 +975,11 @@ class Player(GObject.GObject):
                         grilo.bump_play_count(current_media)
                         grilo.set_last_played(current_media)
                         self._lastfm.scrobble(current_media, self._time_stamp)
-
+            except ZeroDivisionError:
+                # Streams may have no duration set.
+                pass
             except Exception as e:
-                logger.warn("Error: %s, %s", e.__class__, e)
+                logger.warning("Error: {}, {}".format(e.__class__, e))
         return True
 
     @log
@@ -1058,9 +1089,10 @@ class Player(GObject.GObject):
         if not self.currentTrack or not self.currentTrack.valid():
             return None
         currentTrack = self.playlist.get_iter(self.currentTrack.get_path())
-        if self.playlist.get_value(currentTrack, self.discovery_status_field) == DiscoveryStatus.FAILED:
+        failed = DiscoveryStatus.FAILED
+        if self.playlist[currentTrack][self.Field.DISCOVERY_STATUS] == failed:
             return None
-        return self.playlist.get_value(currentTrack, self.playlistField)
+        return self.playlist[currentTrack][self.Field.SONG]
 
 
 class MissingCodecsDialog(Gtk.MessageDialog):
