@@ -82,7 +82,7 @@ class ArtistsView(BaseView):
     @log
     def _on_changes_pending(self, data=None):
         if (self._init
-                and not self._header_bar._selectionMode):
+                and not self._header_bar.selection_mode):
             self.model.clear()
             self._artists.clear()
             self._offset = 0
@@ -121,7 +121,7 @@ class ArtistsView(BaseView):
         try:
             itr = self.model.get_iter(path)
         except ValueError as err:
-            logger.warn("Error: %s, %s", err.__class__, err)
+            logger.warning("Error: {}, {}".format(err.__class__, err))
             return
 
         self._last_selection = itr
@@ -130,11 +130,8 @@ class ArtistsView(BaseView):
         widget = self._artists[artist.casefold()]['widget']
 
         if widget:
-            artist_widget_model = self.player.running_playlist(
-                'Artist', widget.artist)
             artist_stack = self._artist_albums_stack
-            # FIXME: calling to private model
-            if widget._model == artist_widget_model:
+            if self.player.running_playlist('Artist', widget.artist):
                 self._artist_albums_widget = widget.get_parent()
                 GLib.idle_add(self._artist_albums_stack.set_visible_child,
                               self._artist_albums_widget)
@@ -203,8 +200,8 @@ class ArtistsView(BaseView):
     @log
     def _on_selection_mode_changed(self, widget, data=None):
         self._artist_albums_stack.set_sensitive(
-            not self._header_bar._selectionMode)
-        if (not self._header_bar._selectionMode
+            not self._header_bar.selection_mode)
+        if (not self._header_bar.selection_mode
                 and grilo.changes_pending['Artists']):
             self._on_changes_pending()
 
