@@ -23,10 +23,9 @@
 # delete this exception statement from your version.
 
 from gettext import gettext as _, ngettext
-from gi.repository import Gd, Gdk, GdkPixbuf, GObject, Gtk
+from gi.repository import Gd, GdkPixbuf, GObject, Gtk
 
 from gnomemusic import log
-from gnomemusic.albumartcache import AlbumArtCache, DefaultIcon, ArtSize
 from gnomemusic.grilo import grilo
 from gnomemusic.widgets.starhandlerwidget import StarHandlerWidget
 import gnomemusic.utils as utils
@@ -107,11 +106,6 @@ class BaseView(Gtk.Stack):
         self.show_all()
         self._view.hide()
 
-        scale = self.get_scale_factor()
-        self._cache = AlbumArtCache(scale)
-        self._loading_icon_surface = DefaultIcon(scale).get(
-            DefaultIcon.Type.loading, ArtSize.MEDIUM)
-
         self._init = False
         grilo.connect('ready', self._on_grilo_ready)
         self._header_bar.connect('selection-mode-changed',
@@ -151,7 +145,6 @@ class BaseView(Gtk.Stack):
             select_toolbar = self._selection_toolbar
             select_toolbar.actionbar.set_visible(True)
             select_toolbar._add_to_playlist_button.set_sensitive(False)
-            select_toolbar._remove_from_playlist_button.set_sensitive(False)
         else:
             self._header_bar.set_selection_mode(False)
             track_playing = self.player.currentTrack is not None
@@ -161,7 +154,7 @@ class BaseView(Gtk.Stack):
 
     @log
     def _on_cancel_button_clicked(self, button):
-        self._view.set_selection_mode(False)
+        self.unselect_all()
         self._header_bar.set_selection_mode(False)
 
     @log
@@ -190,7 +183,6 @@ class BaseView(Gtk.Stack):
         """Updates header during item selection."""
         select_toolbar = self._selection_toolbar
         select_toolbar._add_to_playlist_button.set_sensitive(n_items > 0)
-        select_toolbar._remove_from_playlist_button.set_sensitive(n_items > 0)
         if n_items > 0:
             self._header_bar._selection_menu_label.set_text(
                 ngettext("Selected {} item",
@@ -213,12 +205,16 @@ class BaseView(Gtk.Stack):
     def populate(self):
         pass
 
+    @log
+    def _retrieval_finished(self, klass):
+        self.model[klass.iter][4] = klass.pixbuf
+
     @log
     def _add_item(self, source, param, item, remaining=0, data=None):
         if not item:
             if remaining == 0:
                 self._view.set_model(self.model)
-                self._window.pop_loading_notification()
+                self._window.notifications_popup.pop_loading()
                 self._view.show()
             return
         self._offset += 1
@@ -226,30 +222,17 @@ class BaseView(Gtk.Stack):
         title = utils.get_media_title(item)
 
         itr = self.model.append(None)
-        loading_icon = Gdk.pixbuf_get_from_surface(
-            self._loadin_icon_surface, 0, 0,
-            self._loading_icon_surface.get_width(),
-            self._loading_icon_surface.get_height())
 
-        self.model[itr][0, 1, 2, 3, 4, 5, 7, 9] = [
+        self.model[itr][0, 1, 2, 3, 5, 7, 9] = [
             str(item.get_id()),
             '',
             title,
             artist,
-            loading_icon,
             item,
             0,
             False
         ]
 
-    @log
-    def _on_lookup_ready(self, surface, itr):
-        if surface:
-            pixbuf = Gdk.pixbuf_get_from_surface(surface, 0, 0,
-                                                 surface.get_width(),
-                                                 surface.get_height())
-            self.model[itr][4] = pixbuf
-
     @log
     def _add_list_renderers(self):
         pass
@@ -287,7 +270,6 @@ class BaseView(Gtk.Stack):
         if count > 0:
             select_toolbar = self._selection_toolbar
             select_toolbar._add_to_playlist_button.set_sensitive(True)
-            select_toolbar._remove_from_playlist_button.set_sensitive(True)
 
         self.update_header_from_selection(count)
         self._view.queue_draw()
@@ -298,7 +280,6 @@ class BaseView(Gtk.Stack):
         self._set_selection(False)
         select_toolbar = self._selection_toolbar
         select_toolbar._add_to_playlist_button.set_sensitive(False)
-        select_toolbar._remove_from_playlist_button.set_sensitive(False)
         self._header_bar._selection_menu_label.set_text(
             _("Click on items to select them"))
         self.queue_draw()
