@@ -27,6 +27,7 @@ from gi.repository import Gd, Gtk
 
 from gnomemusic import log
 from gnomemusic.toolbar import ToolbarState
+from gnomemusic.utils import View
 from gnomemusic.views.baseview import BaseView
 
 
@@ -37,9 +38,10 @@ class EmptySearchView(BaseView):
 
     @log
     def __init__(self, window, player):
-        BaseView.__init__(self, 'emptysearch', None, window, Gd.MainViewType.LIST)
-        self._artistAlbumsWidget = None
-        self._albumWidget = None
+        super().__init__('emptysearch', None, window, Gd.MainViewType.LIST)
+
+        self._artist_albums_widget = None
+
         self.player = player
 
         builder = Gtk.Builder()
@@ -47,17 +49,19 @@ class EmptySearchView(BaseView):
         widget = builder.get_object('container')
         widget.set_vexpand(True)
         widget.set_hexpand(True)
-        widget.get_children()[1].get_children()[1].set_text(_("Try a different search"))
+        widget.get_children()[1].get_children()[1].set_text(
+            _("Try a different search"))
         widget.show_all()
         self._box.add(widget)
 
     @log
     def _back_button_clicked(self, widget, data=None):
-        self.header_bar.searchbar.show_bar(True, False)
-        if self.get_visible_child() == self._artistAlbumsWidget:
-            self._artistAlbumsWidget.destroy()
-            self._artistAlbumsWidget = None
+        self._header_bar.searchbar.reveal(True, False)
+        if self.get_visible_child() == self._artist_albums_widget:
+            self._artist_albums_widget.destroy()
+            self._artist_albums_widget = None
         elif self.get_visible_child() == self._grid:
-            self.window.views[0].set_visible_child(self.window.views[0]._grid)
-            self.window.toolbar.set_state(ToolbarState.CHILD_VIEW)
+            self._window.views[View.ALBUM].set_visible_child(
+                self._window.views[View.ALBUM]._grid)
+            self._window.toolbar.set_state(ToolbarState.CHILD_VIEW)
         self.set_visible_child(self._grid)
