@@ -143,7 +143,7 @@ class SearchView(BaseView):
             if self.model[_iter][12] != DiscoveryStatus.FAILED:
                 c_iter = self._songs_model.convert_child_iter_to_iter(_iter)[1]
                 self.player.set_playlist(
-                    'Search Results', None, self._songs_model, c_iter, 5, 12)
+                    'Search Results', None, self._songs_model, c_iter, 12)
                 self.player.set_playing(True)
         else:  # Headers
             if self._view.get_generic_view().row_expanded(path):
@@ -156,7 +156,7 @@ class SearchView(BaseView):
         if (self._artist_albums_widget is not None
                 and self.get_visible_child() == self._artist_albums_widget):
             self._artist_albums_widget.set_selection_mode(
-                self._header_bar._selectionMode)
+                self._header_bar.selection_mode)
 
     @log
     def _add_search_item(self, source, param, item, remaining=0, data=None):
@@ -306,6 +306,15 @@ class SearchView(BaseView):
 
         self._star_handler.add_star_renderers(list_widget, cols[0])
         cells = cols[0].get_cells()
+
+        # With the bugfix in libgd 9117650bda, the search results
+        # stopped aligning at the top. With the artists results not
+        # having a second line of text, this looks off.
+        # Revert to old behaviour by forcing the alignment to be top.
+        # FIXME: Revisit this when rewriting the searchview.
+        gd_twolines_renderer = cells[2]
+        gd_twolines_renderer.props.yalign = 0
+
         cols[0].reorder(cells[0], -1)
         cols[0].reorder(cells[4], 1)
         cols[0].set_cell_data_func(
