@@ -69,7 +69,7 @@ class SongsView(BaseView):
     @log
     def _on_changes_pending(self, data=None):
         if (self._init
-                and not self._header_bar._selectionMode):
+                and not self._header_bar.selection_mode):
             self.model.clear()
             self._offset = 0
             GLib.idle_add(self.populate)
@@ -77,7 +77,7 @@ class SongsView(BaseView):
 
     @log
     def _on_selection_mode_changed(self, widget, data=None):
-        if (not self._header_bar._selectionMode
+        if (not self._header_bar.selection_mode
                 and grilo.changes_pending['Songs']):
             self._on_changes_pending()
 
@@ -90,11 +90,11 @@ class SongsView(BaseView):
         try:
             itr = self.model.get_iter(path)
         except ValueError as err:
-            logger.warn("Error: {}, {}".format(err.__class__, err))
+            logger.warning("Error: {}, {}".format(err.__class__, err))
             return
 
         if self.model[itr][8] != self._error_icon_name:
-            self.player.set_playlist('Songs', None, self.model, itr, 5, 11)
+            self.player.set_playlist('Songs', None, self.model, itr)
             self.player.set_playing(True)
 
     @log
@@ -107,14 +107,16 @@ class SongsView(BaseView):
         """
         if self._iter_to_clean:
             self.model[self._iter_to_clean][10] = False
-        if playlist != self.model:
+        if not player.running_playlist('Songs', None):
             return False
 
-        self.model[current_iter][10] = True
-        path = self.model.get_path(current_iter)
+        pos_str = playlist.get_path(current_iter).to_string()
+        iter_ = self.model.get_iter_from_string(pos_str)
+        self.model[iter_][10] = True
+        path = self.model.get_path(iter_)
         self._view.get_generic_view().scroll_to_path(path)
-        if self.model[current_iter][8] != self._error_icon_name:
-            self._iter_to_clean = current_iter.copy()
+        if self.model[iter_][8] != self._error_icon_name:
+            self._iter_to_clean = iter_.copy()
         return False
 
     def _add_item(self, source, param, item, remaining=0, data=None):
@@ -219,7 +221,7 @@ class SongsView(BaseView):
             cell.set_property('text', utils.get_album_title(item))
 
     def _on_list_widget_icon_render(self, col, cell, model, itr, data):
-        track_uri = self.player.currentTrackUri
+        track_uri = self.player.current_track_uri
         if not track_uri:
             cell.set_visible(False)
             return
