@@ -22,7 +22,7 @@
 # code, but you are not obligated to do so.  If you do not wish to do so,
 # delete this exception statement from your version.
 
-from gi.repository import Gtk, Gd, Pango
+from gi.repository import Gtk, Pango
 
 from gnomemusic import log
 from gnomemusic.grilo import grilo
@@ -37,7 +37,7 @@ class PlaylistDialog():
         return '<PlaylistDialog>'
 
     @log
-    def __init__(self, parent):
+    def __init__(self, parent, playlists_todelete):
         self._ui = Gtk.Builder()
         self._ui.add_from_resource('/org/gnome/Music/PlaylistDialog.ui')
 
@@ -47,10 +47,12 @@ class PlaylistDialog():
         self._add_playlist_stack = self._ui.get_object('add_playlist_stack')
         self._normal_state = self._ui.get_object('normal_state')
         self._empty_state = self._ui.get_object('empty_state')
-        self._title_bar = self._ui.get_object('headerbar1')
+        self._title_bar = self._ui.get_object('headerbar')
         self._dialog_box.set_titlebar(self._title_bar)
         self._setup_dialog()
 
+        self._playlists_todelete_ids = playlists_todelete.keys()
+
         self._playlist = Playlists.get_default()
 
     @log
@@ -65,14 +67,14 @@ class PlaylistDialog():
 
     @log
     def _setup_dialog(self):
-        self._view = self._ui.get_object('treeview1')
+        self._view = self._ui.get_object('treeview')
         self._view.set_activate_on_single_click(False)
-        self._selection = self._ui.get_object('treeview-selection1')
+        self._selection = self._ui.get_object('treeview-selection')
         self._selection.connect('changed', self._on_selection_changed)
         self._add_list_renderers()
         self._view.connect('row-activated', self._on_item_activated)
 
-        self._model = self._ui.get_object('liststore1')
+        self._model = self._ui.get_object('liststore')
         self._populate()
 
         self._cancel_button = self._ui.get_object('cancel-button')
@@ -116,21 +118,18 @@ class PlaylistDialog():
         """Get the selected playlist"""
         _iter = self._selection.get_selected()[1]
 
-        if not _iter or self._model[_iter][1]:
+        if not _iter:
             return None
 
-        return self._model[_iter][2]
+        return self._model[_iter][1]
 
     @log
     def _add_list_renderers(self):
-        type_renderer = Gd.StyledTextRenderer(
+        type_renderer = Gtk.CellRendererText(
             xpad=8, ypad=8, ellipsize=Pango.EllipsizeMode.END, xalign=0.0)
 
-        cols = Gtk.TreeViewColumn()
-        cols.pack_start(type_renderer, True)
-        cols.add_attribute(type_renderer, "text", 0)
-        cols.set_cell_data_func(type_renderer, self._on_list_text_render)
-        self._view.append_column(cols)
+        col = Gtk.TreeViewColumn("Name", type_renderer, text=0)
+        self._view.append_column(col)
 
     @log
     def _populate(self):
@@ -149,21 +148,15 @@ class PlaylistDialog():
         if self._playlist.is_static_playlist(item):
             return None
 
-        new_iter = self._model.append()
-        self._model[new_iter][0, 1, 2] = [
-            utils.get_media_title(item), False, item
-        ]
+        # Hide playlists that are going to be deleted
+        if item.get_id() in self._playlists_todelete_ids:
+            return None
+
+        new_iter = self._model.insert_with_valuesv(
+            -1, [0, 1], [utils.get_media_title(item), item])
 
         return new_iter
 
-    @log
-    def _on_list_text_render(self, col, cell, model, _iter, data):
-        editable = model[_iter][1]
-        if editable:
-            cell.add_class("dim-label")
-        else:
-            cell.remove_class("dim-label")
-
     @log
     def _on_selection(self, select_button):
         self._dialog_box.response(Gtk.ResponseType.ACCEPT)
@@ -185,11 +178,7 @@ class PlaylistDialog():
     @log
     def _on_selection_changed(self, selection):
         model, _iter = self._selection.get_selected()
-
-        if _iter is None or self._model[_iter][1]:
-            self._select_button.set_sensitive(False)
-        else:
-            self._select_button.set_sensitive(True)
+        self._select_button.set_sensitive(_iter is not None)
 
     @log
     def _on_editing_done(self, sender, data=None):
